@@ -1,12 +1,9 @@
 from __future__ import absolute_import
 
 # for exposure to from sunpy.net.vso import *
-from sunpy.net.vso.vso import VSOClient, InteractiveVSOClient
+from sunpy.net.vso.vso import VSOClient, InteractiveVSOClient, QueryResponse
 
-# for, e.g.,
-# >>> from sunpy.net import vso
-# >>> vso.search(...)
-# >>> vso.get(...)
+# Delete this in 0.9
 from sunpy.net.vso.vso import search, get
 
 __all__ = ['VSOClient', 'InteractiveVSOClient']
